document.addEventListener('DOMContentLoaded', () => {
  const questionInput = document.getElementById('questionInput');
  const submitButton = document.getElementById('submitButton');
  const solutionArea = document.getElementById('solutionArea');
  const historyList = document.getElementById('historyList');
  const loadingSpinner = document.querySelector('.loading-spinner');

  // Load history from localStorage
  let questionHistory = JSON.parse(localStorage.getItem('mathHistory')) || [];
  
  // Render initial history
  renderHistory();

  function addToHistory(question, answer) {
    const historyItem = {
      id: Date.now(),
      question,
      answer,
      timestamp: new Date().toISOString()
    };
    
    questionHistory.unshift(historyItem);
    
    // Keep only last 50 questions
    if (questionHistory.length > 50) {
      questionHistory.pop();
    }
    
    localStorage.setItem('mathHistory', JSON.stringify(questionHistory));
    renderHistory();
  }

  function renderHistory() {
    historyList.innerHTML = questionHistory.map(item => `
      <div class="history-item" data-id="${item.id}">
        <p><strong>Q:</strong> ${item.question}</p>
        <small>${new Date(item.timestamp).toLocaleString()}</small>
      </div>
    `).join('');

    // Add click listeners to history items
    document.querySelectorAll('.history-item').forEach(item => {
      item.addEventListener('click', () => {
        const historyItem = questionHistory.find(h => h.id === parseInt(item.dataset.id));
        if (historyItem) {
          solutionArea.querySelector('.solution-content').innerHTML = `
            <h3>Question:</h3>
            <p>${historyItem.question}</p>
            <h3>Solution:</h3>
            <p>${historyItem.answer}</p>
          `;
          solutionArea.classList.remove('hidden');
        }
      });
    });
  }

  async function handleQuestionSubmit() {
    const question = questionInput.value.trim();
    
    if (!question) return;

    loadingSpinner.classList.remove('hidden');
    solutionArea.querySelector('.solution-content').innerHTML = '';

    try {
      // Here you would integrate with Claude AI
      // For demo purposes, we'll simulate a response
      const answer = await simulateClaudeResponse(question);
      
      solutionArea.querySelector('.solution-content').innerHTML = `
        <h3>Question:</h3>
        <p>${question}</p>
        <h3>Solution:</h3>
        <p>${answer}</p>
      `;
      
      addToHistory(question, answer);
      
    } catch (error) {
      solutionArea.querySelector('.solution-content').innerHTML = `
        <p class="error">Sorry, there was an error processing your question. Please try again.</p>
      `;
    } finally {
      loadingSpinner.classList.add('hidden');
      solutionArea.classList.remove('hidden');
    }
  }

  // Simulate Claude AI response (replace with actual Claude integration)
  async function simulateClaudeResponse(question) {
    return new Promise(resolve => {
      setTimeout(() => {
        resolve(`This is a simulated answer to your question: "${question}". In a real implementation, this would be handled by Claude AI.`);
      }, 1500);
    });
  }

  submitButton.addEventListener('click', handleQuestionSubmit);
  
  questionInput.addEventListener('keypress', (e) => {
    if (e.key === 'Enter' && !e.shiftKey) {
      e.preventDefault();
      handleQuestionSubmit();
    }
  });
});
